<?php
/**
 * Aryx functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Aryx
 * @since 1.0
 */

if ( ! function_exists( 'aryx_setup' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 */
	function aryx_setup() {
		/*
		 * Make theme available for translation.
		 */
		load_theme_textdomain( 'aryx', get_template_directory() . '/languages' );

		/*
		 * Add default posts and comments RSS feed links to head.
		 */
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Register Navigation Menus
		 */
		register_nav_menus( array(
			'menu-header' => esc_html__( 'Header Navigation Menu', 'aryx' ),
			'menu-footer' => esc_html__( 'Footer Menu', 'aryx' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) );

		/*
		 * Add theme support for selective refresh for widgets.
		 */
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true
		) );

	}
}
add_action( 'after_setup_theme', 'aryx_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * @global int $content_width
 */
function aryx_content_width() {
	// This variable is intended to be overruled from themes.
	$GLOBALS['content_width'] = apply_filters( 'aryx_content_width', 640 );
}
add_action( 'after_setup_theme', 'aryx_content_width', 0 );

/**
 * Register Breadcrumb
 */
function aryx_breadcrumb() {
    $breadcrumb_separator = sanitize_text_field( get_theme_mod( 'aryx_f_breadcrumb_separator_s_breadcrumb_p_header', '>>' ) );
    if ( !is_front_page() ){
        echo '<div class="row breadcrumb"><a href="'.esc_url( home_url( '/' ) ).'" rel="nofollow">Home</a>';
        if ( is_category() || is_single() ) {
            echo '&nbsp;&nbsp;' . $breadcrumb_separator . '&nbsp;&nbsp;';
            the_category( ',&nbsp;' );
                if ( is_single() ) {
                    echo '&nbsp;&nbsp;' . $breadcrumb_separator . '&nbsp;&nbsp;';
                    the_title();
                }
        } elseif ( is_page() ) {
            echo '&nbsp;&nbsp;' . $breadcrumb_separator . '&nbsp;&nbsp;' . get_the_title();
        } elseif ( is_search() ) {
            echo '&nbsp;&nbsp;' . $breadcrumb_separator . '&nbsp;&nbsp;Search Results for "';
            the_search_query();
            echo '"';
        }
        echo '</div>';
    }
}

/**
 * Enqueue classic editor styles.
 */
function aryx_classic_editor_styles() {
	$classic_editor_styles = array(	
		'/assets/dist/editor/bundled/css/aryx-editor-bundled.min.css',		$asset_optimization = get_theme_mod( 'aryx_f_asset_optimization_s_asset_optimization_p_optimization', true )
	);	
	if ( $asset_optimization == 'minified' ) {
		$classic_editor_styles = array(
			'/assets/dist/editor/raw/css/aryx-editor.min.css',
		);
	} else {
		$classic_editor_styles = array(
			'/assets/dist/editor/raw/css/aryx-editor.css',
		);
	}

	add_editor_style( $classic_editor_styles );

}

/**
 * Register widget area(s).
 *
 */
function aryx_widgets_init() {

	register_sidebar(
		array(
			'name'          => esc_html__( 'Main Sidebar', 'aryx' ),
			'id'            => 'main-sidebar',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Shop Sidebar', 'aryx' ),
			'id'            => 'shop',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'			=> esc_html__( 'Footer Widget Area 1', 'aryx' ),
			'id'            => 'footer-widget-area-1',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'			=> esc_html__( 'Footer Widget Area 2', 'aryx' ),
			'id'            => 'footer-widget-area-2',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'			=> esc_html__( 'Footer Widget Area 3', 'aryx' ),
			'id'            => 'footer-widget-area-3',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'			=> esc_html__( 'Footer Widget Area 4', 'aryx' ),
			'id'            => 'footer-widget-area-4',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

}
add_action( 'widgets_init', 'aryx_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
require get_template_directory() . '/inc/assets.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/compatibility/jetpack/jetpack.php';
}
/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/compatibility/woocommerce/woocommerce.php';
}
/**
 * Load bbPress compatibility file.
 */
if ( class_exists( 'bbPress' ) ) {
    require get_template_directory() . '/inc/compatibility/bbpress/bbpress.php';
}
/**
 * Load Bootstrap Navwalker
 */
require_once get_template_directory() . '/inc/bootstrap-navwalker/class-wp-bootstrap-navwalker.php';


/**
 * Custom Page Metaboxes
 */
require_once get_template_directory() . '/inc/metaboxes/aryx-page-settings.php';

/**
 * TGMPA Class
 */
require_once get_parent_theme_file_path( '/inc/tgmpa/class-tgmpa.php' );

/**
 * TGMPA Configuration
 */
require_once get_parent_theme_file_path( '/inc/tgmpa-config.php' );