<?php
/**
 * The header for Aryx
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Aryx
 * @since 1.0
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php wp_head(); ?>
		<?php echo '<meta name="google-site-verification" content="' . get_theme_mod('aryx_f_google_s_verification_p_seo') . '" />'; ?>
		<?php echo '<meta name="msvalidate.01" content="' . get_theme_mod('aryx_f_bing_s_verification_p_seo') . '" />'; ?>
	</head>
	<body <?php body_class(); ?>>
		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'aryx' ); ?></a>
		<?php
            if ( function_exists( 'wp_body_open' ) ) {
                wp_body_open();
            } else {
                do_action( 'wp_body_open' );
            }

		$header_layout = get_theme_mod( 'aryx_f_header_layout_s_header_settings_p_header', 'left' );
		$sticky_header = get_theme_mod( 'aryx_f_enable_sticky_header_s_header_settings_p_header', '' );
		$primary_menu_disabled = get_theme_mod( 'aryx_f_disable_primary_menu_s_primary_menu_p_header', '1' );
		if ( $header_layout != 'none' ) {
		?>
		<header id="masthead" class="site-header">
			<nav id="primary-nav" class="navbar navbar-light navbar-expand-lg <?php echo 'header-' . $header_layout; ?><?php echo ($sticky_header == 1) ? ' fixed-top' : ''; ?>">
				<?php
				$header_width = get_theme_mod( 'aryx_f_header_width_s_header_settings_p_header', 'container-width' );
				$archive_content_layout = get_theme_mod( 'aryx_f_archive_content_layout_s_container_p_layout', 'default-width' );
				$default_content_layout = get_theme_mod( 'aryx_f_default_content_layout_s_container_p_layout', 'fixed-width' );
				$page_content_layout = get_theme_mod( 'aryx_f_page_content_layout_s_container_p_layout', 'default-width' );
				$post_content_layout = get_theme_mod( 'aryx_f_post_content_layout_s_container_p_layout', 'default-width' );
				$inpost_content_layout = get_post_meta( !empty($post->ID) ? $post->ID : '', 'aryx_content_layout', true );
				if ( $header_width ) {
					if ( $header_width == 'full-width' ) {
						echo '<div class="container-fluid">';
					} elseif ( $header_width == 'fixed-width' ) {
						echo '<div class="container">';
					} elseif ( $header_width == 'container-width' ) {
						if ( is_archive() || is_home() ) {
							if ( $archive_content_layout == 'default-width' ) {
								if ( $default_content_layout == 'fixed-width' ) {
									echo '<div class="container">';
								} elseif ( $default_content_layout == 'full-width' ) {
									echo '<div class="container-fluid">';
								}
							} elseif ( $archive_content_layout == 'fixed-width' ) {
								echo '<div class="container">';
							} elseif ( $archive_content_layout == 'full-width' ) {
								echo '<div class="container-fluid">';
							}
						} elseif ( is_single() ) {
							if ( ! $inpost_content_layout || $inpost_content_layout == 'customizer-default' ) {
								if ( $post_content_layout == 'default-width' ) {
									if ( $default_content_layout == 'fixed-width' ) {
										echo '<div class="container">';
									} elseif ( $default_content_layout == 'full-width' ) {
										echo '<div class="container-fluid">';
									}
								} elseif ( $post_content_layout == 'fixed-width' ) {
									echo '<div class="container">';
								} elseif ( $post_content_layout == 'full-width' ) {
									echo '<div class="container-fluid">';
								}
							} elseif ( $inpost_content_layout == 'boxed' ) {
									echo '<div class="container">';
							} elseif ( $inpost_content_layout == 'full-width' ) {
								echo '<div class="container-fluid">';
							}
						} elseif ( is_page() ) {
							if ( ! $inpost_content_layout || $inpost_content_layout == 'customizer-default' ) {
								if ( $page_content_layout == 'default-width' ) {
									if ( $default_content_layout == 'fixed-width' ) {
										echo '<div class="container">';
									} elseif ( $default_content_layout == 'full-width' ) {
										echo '<div class="container-fluid">';
									}
								} elseif ( $page_content_layout == 'fixed-width' ) {
									echo '<div class="container">';
								} elseif ( $page_content_layout == 'full-width' ) {
									echo '<div class="container-fluid">';
								}
							} elseif ( $inpost_content_layout == 'boxed' ) {
									echo '<div class="container">';
							} elseif ( $inpost_content_layout == 'full-width' ) {
								echo '<div class="container-fluid">';
							}
						} else {
							if ( $default_content_layout == 'fixed-width' ) {
								echo '<div class="container">';
							} elseif ( $default_content_layout == 'full-width' ) {
								echo '<div class="container-fluid">';
							}
						}
					}
				} else {
					echo '<div class="container">';
				}
				/* Positioning Logo and Menu Based on Header Layout */
				if ( $header_layout == 'left' ) {
					$menu_alignment = 'ml-auto';
					$branding_order = 'order-first';
				} elseif ( $header_layout == 'center' ) {
					$menu_alignment = 'm-auto';
					$menu_toggler_alignment = 'aligncenter';
				} elseif ( $header_layout == 'right' ) {
					$menu_alignment = 'mr-auto';
					$branding_order = 'order-last';
				}
				?>
				<div class="site-branding <?php echo !empty($branding_order) ? $branding_order : $menu_alignment; ?>">
					<?php if( has_custom_logo() ) {
						echo get_custom_logo();
					} else { ?>
                        <a class="navbar-brand" href="<?php echo esc_url( home_url('/') ); ?>">
							<h3><?php echo esc_html( get_bloginfo( 'name', 'display' ) ); ?></h3>
						</a>
					<?php } ?>
				</div>
				<?php if ( $primary_menu_disabled ) { ?>
					<button class="navbar-toggler <?php echo !empty($menu_toggler_alignment) ? $menu_toggler_alignment : ''; ?>" type="button" data-toggle="collapse" data-target="#header-nav-collapse" aria-controls="header-nav-collapse" aria-expanded="false" aria-label="<?php esc_attr_e( 'Toggle Navigation', 'aryx' ); ?>">
						<span class="navbar-toggler-icon"></span>
					</button>
					<?php
					wp_nav_menu( array(
						'theme_location'    => 'menu-header',
						'depth'             => 2,
						'container'         => 'div',
						'container_class'   => 'collapse navbar-collapse',
						'container_id'      => 'header-nav-collapse',
						'menu_class'        => 'navbar-nav text-center ' . $menu_alignment,
						'fallback_cb'       => 'WP_Bootstrap_Navwalker::fallback',
						'walker'            => new WP_Bootstrap_Navwalker(),
					) );					
				}
				?>
		      	</div>
		    </nav>
		</header>
		<?php
		}
		?>	
		<main id="main" class="site-main">