<?php
/**
 * WooCommerce Compatibility File
 *
 * @link https://woocommerce.com/
 *
 * @package Aryx
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */

function aryx_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'aryx' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'aryx_woocommerce_setup' );

/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
add_filter( 'woocommerce_enqueue_styles', '__return_false' );

function aryx_wc_scripts() {

	/*
	 * This is temporarily targetted to the vendors folder.
	 * We'll introduce a condition in the theme to let the user
	 * choose if they want to deliver optimized files or raw files.
	 * Depending on the choice, we'll enqueue raw files from the vendors folder
	 * or optimized (combined and minified) file from the dist folder
	 */
	wp_enqueue_style( 'aryx-woocommerce-layout', get_template_directory_uri() . '/assets/compatibility/woocommerce/css/aryx-woocommerce-layout.css' );
	wp_enqueue_style( 'aryx-woocommerce-style', get_template_directory_uri() . '/assets/compatibility/woocommerce/css/aryx-woocommerce.css' );


	$font_path   = WC()->plugin_url() . '/assets/fonts/';
	$inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				 url("' . $font_path . 'star.woff") format("woff"),
				 url("' . $font_path . 'star.ttf") format("truetype"),
				 url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: 400;
			font-style: normal;
		}
		@font-face {
			font-family: "WooCommerce";
			src: url("' . $font_path . 'WooCommerce.eot");
			src: url("' . $font_path . 'WooCommerce.eot?#iefix") format("embedded-opentype"),
				 url("' . $font_path . 'WooCommerce.woff") format("woff"),
				 url("' . $font_path . 'WooCommerce.ttf") format("truetype"),
				 url("' . $font_path . 'WooCommerce.svg#star") format("svg");
			font-weight: 400;
			font-style: normal;
		}';

	wp_add_inline_style( 'aryx-woocommerce-style', $inline_font );
}
add_action( 'wp_enqueue_scripts', 'aryx_wc_scripts' );

remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);

function aryx_wc_star_rating()
{
    global $woocommerce, $product;
    $average = $product->get_average_rating();

    echo '<div class="star-rating"><span style="width:'.( ( $average / 5 ) * 100 ) . '%"><strong itemprop="ratingValue" class="rating">'.$average.'</strong> '.__( 'out of 5', 'aryx' ).'</span></div>';
}
add_action('woocommerce_after_shop_loop_item_title', 'aryx_wc_star_rating', 5 );