<?php
/**
 * Add page settings metaboxes
 *
 * @package Aryx
 */

/**
 * Add Page Settings Metabox
 */
function aryx_post_meta_box_add() {

	add_meta_box( 'aryx_page_settings_meta_box', __( 'Aryx Settings', 'aryx' ), 'aryx_page_settings_meta_box_callback', array( 'page', 'post' ), 'side', 'default' );
}
add_action( 'add_meta_boxes', 'aryx_post_meta_box_add' );

function aryx_page_settings_meta_box_callback( $post ) {

	$values = get_post_custom( $post->ID );

	$aryx_sidebar = ( isset( $values[ 'aryx_sidebar' ][ 0 ] ) && '' !== $values[ 'aryx_sidebar' ][ 0 ] ) ? $values[ 'aryx_sidebar' ][ 0 ] : '';

	$aryx_content_layout = ( isset( $values[ 'aryx_content_layout' ][ 0 ] ) && '' !== $values[ 'aryx_content_layout' ][ 0 ] ) ? $values[ 'aryx_content_layout' ][ 0 ] : '';

	$aryx_transparent_header = ( isset( $values[ 'aryx_transparent_header' ][ 0 ] ) && '' !== $values[ 'aryx_transparent_header' ][ 0 ] ) ? $values[ 'aryx_transparent_header' ][ 0 ] : '';

	$aryx_disable_title = ( isset( $values[ 'aryx_disable_title' ][ 0 ] ) && '' !== $values[ 'aryx_disable_title' ][ 0 ] ) ? $values[ 'aryx_disable_title' ][ 0 ] : '';

	wp_nonce_field( 'aryx_meta_box_nonce', 'meta_box_nonce' );
	?>

    <div class="aryx-page-settings-metabox">
        <div class="components-base-control__field">
            <p class="post-attributes-label-wrapper"><strong><?php esc_html_e( 'Sidebar', 'aryx' ); ?></strong></p>
            <select name="aryx_sidebar" id="aryx_sidebar">
                <option value="customizer-default" <?php selected( $aryx_sidebar, 'customizer-default' ); ?>><?php esc_html_e( 'Customizer Default', 'aryx' ); ?></option>
            	<option value="no-sidebar" <?php selected( $aryx_sidebar, 'no-sidebar' ); ?>><?php esc_html_e( 'No Sidebar', 'aryx' ); ?></option>
            	<option value="left-sidebar" <?php selected( $aryx_sidebar, 'left-sidebar' ); ?>><?php esc_html_e( 'Left Sidebar', 'aryx' ); ?></option>
            	<option value="right-sidebar" <?php selected( $aryx_sidebar, 'right-sidebar' ); ?>><?php esc_html_e( 'Right Sidebar', 'aryx' ); ?></option>
            </select>
        </div>

        <div class="components-base-control__field">
            <p class="post-attributes-label-wrapper"><strong><?php esc_html_e( 'Content Layout', 'aryx' ); ?></strong></p>
            <select name="aryx_content_layout" id="aryx_content_layout">
                <option value="customizer-default" <?php selected( $aryx_content_layout, 'customizer-default' ); ?>><?php esc_html_e( 'Customizer Default', 'aryx' ); ?></option>
            	<option value="boxed" <?php selected( $aryx_content_layout, 'boxed' ); ?>><?php esc_html_e( 'Boxed', 'aryx' ); ?></option>
            	<option value="full-width" <?php selected( $aryx_content_layout, 'full-width' ); ?>><?php esc_html_e( 'Full Width', 'aryx' ); ?></option>
            </select>
        </div>

        <div class="components-base-control__field">
            <p class="post-attributes-label-wrapper"><strong><?php esc_html_e( 'Transparent Header', 'aryx' ); ?></strong></p>
            <select name="aryx_transparent_header" id="aryx_transparent_header">
                <option value="customizer-default" <?php selected( $aryx_transparent_header, 'customizer-default' ); ?>><?php esc_html_e( 'Customizer Default', 'aryx' ); ?></option>
            	<option value="disabled" <?php selected( $aryx_transparent_header, 'disabled' ); ?>><?php esc_html_e( 'Disabled', 'aryx' ); ?></option>
            	<option value="enabled" <?php selected( $aryx_transparent_header, 'enabled' ); ?>><?php esc_html_e( 'Enabled', 'aryx' ); ?></option>
            </select>
        </div>

        <div class="components-base-control__field">
            <p class="post-attributes-label-wrapper"><strong><?php esc_html_e( 'Disable Sections', 'aryx' ); ?></strong></p>
            <label>
            	<input type="checkbox" value="disabled" name="aryx_disable_title" <?php checked( $aryx_disable_title, 'disabled' ); ?>>
            	<?php esc_html_e( 'Disable Title', 'aryx' ); ?>
            </label>
        </div>
    </div>
    <?php
}

function aryx_post_meta_box_save( $post_id ) {

    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;

    if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'aryx_meta_box_nonce' ) ) return;

    if( !current_user_can( 'edit_posts' ) ) return;

    // Sidebar
    if( isset( $_POST['aryx_sidebar'] ) )
        update_post_meta( $post_id, 'aryx_sidebar', sanitize_title_with_dashes( $_POST['aryx_sidebar'] ) );

    // Content Layout
    if( isset( $_POST['aryx_content_layout'] ) )
        update_post_meta( $post_id, 'aryx_content_layout', sanitize_title_with_dashes( $_POST['aryx_content_layout'] ) );

    // Title Display
    if( isset( $_POST['aryx_transparent_header'] ) )
        update_post_meta( $post_id, 'aryx_transparent_header', sanitize_title_with_dashes( $_POST['aryx_transparent_header'] ) );

    // Header Layout
    if( isset( $_POST['aryx_disable_title'] ) ) {
        update_post_meta( $post_id, 'aryx_disable_title', sanitize_title_with_dashes( $_POST['aryx_disable_title'] ) );
    } else {
        update_post_meta( $post_id, 'aryx_disable_title', '' );
    }
}
add_action( 'save_post', 'aryx_post_meta_box_save' );

/**
 * Aryx SEO Metabox
 */
function aryx_add_seo_meta_box()
{
    $post_types = get_post_types( array('public' => true) );
    foreach( $post_types as $post_type )
    {
        add_meta_box(
            'aryx_seo_meta_box',           // Unique ID
            'Aryx SEO Settings',  // Box title
            'aryx_seo_meta_box_markup',  // Content callback, must be of type callable
            $post_type                   // Post type
        );
    }
}
add_action('add_meta_boxes', 'aryx_add_seo_meta_box');

function aryx_seo_meta_box_markup($post)
{
    wp_nonce_field( 'aryx_seo_meta_box_nonce_verify', 'aryx_seo_meta_box_nonce' );
    ?>
    <div>
        <p>SEO Focus Keyword</p>
        <input type="text" name="aryx_focus_keyword" class="text" value="<?php echo get_post_meta($post->ID, '_aryx_focus_keyword', true); ?>"></input>
    </div>
    <div>
        <p>SEO Meta Title</p>
        <input type="text" name="aryx_meta_title" class="text" value="<?php echo get_post_meta($post->ID, '_aryx_meta_title', true); ?>"></input>
    </div>
    <div>
        <p>SEO Meta Description</p>
        <textarea name="aryx_meta_description" class="text"><?php echo get_post_meta($post->ID, '_aryx_meta_description', true); ?></textarea>
    </div>
    <?php
}

function wporg_save_postdata($post_id)
{
    if ( ! isset( $_POST['aryx_seo_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['aryx_seo_meta_box_nonce'], 'aryx_seo_meta_box_nonce_verify' ) ){
        return;
    }
    // return if autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
        return;
    }
    if ( ! current_user_can( 'edit_post', $post_id ) ){
        return;
    }
    if ( isset( $_POST['aryx_focus_keyword'] ) ) {
        update_post_meta(
            $post_id,
            '_aryx_focus_keyword',
            sanitize_text_field($_POST['aryx_focus_keyword'])
        );
    }
    if ( isset( $_POST['aryx_meta_title'] ) ) {
        update_post_meta(
            $post_id,
            '_aryx_meta_title',
            sanitize_text_field($_POST['aryx_meta_title'])
        );
    }
    if ( isset( $_POST['aryx_meta_description'] ) ) {
        update_post_meta(
            $post_id,
            '_aryx_meta_description',
            sanitize_text_field($_POST['aryx_meta_description'])
        );
    }
}
add_action('save_post', 'wporg_save_postdata');