<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Aryx
 * @since 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function aryx_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'main-sidebar' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Transparent Header Class
	global $post;
	$inpage_transparent_header = get_post_meta( !empty($post->ID) ? $post->ID : '', 'aryx_transparent_header', true );
	$global_transparent_header = get_theme_mod( 'aryx_f_enable_s_transparent_header_p_header', '' );

	if ( is_home() || is_archive() || ! $inpage_transparent_header || $inpage_transparent_header == 'customizer-default' ) {

		if ( $global_transparent_header == true ) {
			$classes[] = 'transparent-header';
		}

	} elseif ( $inpage_transparent_header == 'enabled' ) {
		$classes[] = 'transparent-header';
	}

	return $classes;
}
add_filter( 'body_class', 'aryx_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function aryx_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'aryx_pingback_header' );

/**
 * Filters the default archive titles.
 */
function aryx_get_the_archive_title() {
	if ( is_category() ) {
		$title = __( '<p class="archive-term">Category</p>', 'aryx' ) . '<h2 class="page-title">' . single_term_title( '', false ) . '</h2>';
	} elseif ( is_tag() ) {
		$title = __( '<p class="archive-term">Tag</p>', 'aryx' ) . '<h2 class="page-title">' . single_term_title( '', false ) . '</h2>';
	} elseif ( is_author() ) {
		$title = __( '<p class="archive-term">Author</p>', 'aryx' ) . '<h2 class="page-title">' . get_the_author_meta( 'display_name' ) . '</h2>';
	} elseif ( is_year() ) {
		$title = __( '<p class="archive-term">Yearly</p>', 'aryx' ) . '<h2 class="page-title">' . get_the_date( _x( 'Y', 'yearly archives date format', 'aryx' ) ) . '</h2>';
	} elseif ( is_month() ) {
		$title = __( '<p class="archive-term">Monthly</p>', 'aryx' ) . '<h2 class="page-title">' . get_the_date( _x( 'F Y', 'monthly archives date format', 'aryx' ) ) . '</h2>';
	} elseif ( is_day() ) {
		$title = __( '<p class="archive-term">Daily</p>', 'aryx' ) . '<h2 class="page-title">' . get_the_date() . '</h2>';
	} elseif ( is_post_type_archive() ) {
		$title = __( '<p class="archive-term">Post Types</p>', 'aryx' ) . '<h2 class="page-title">' . post_type_archive_title( '', false ) . '</h2>';
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: %s: Taxonomy singular name */
		$title = sprintf( esc_html__( '%s Archives:', 'aryx' ), $tax->labels->singular_name );
	} else {
		$title = __( 'Archives:', 'aryx' );
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'aryx_get_the_archive_title' );
