<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Aryx
 * @since 1.0
 */
if ( ! function_exists( 'aryx_entry_meta' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function aryx_entry_meta() {
		if (get_the_time( 'U' )) {
			$published_time = '<time class="entry-date published" datetime="%1$s">Published on %2$s</time>';
		}
		$published_time = sprintf( $published_time,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() )
		);
		$published_time = sprintf(
			/* translators: %s: post date. */
            '%s',
			$published_time
		);

		$published = '<span class="published-on">' . $published_time . '</span>'; // WPCS: XSS OK.
		if (get_the_modified_time( 'U' )) {
			$modified_time = '<time class="entry-date published" datetime="%1$s">Modified on %2$s</time>';
		}
		$modified_time = sprintf( $modified_time,
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);
		$modified_time = sprintf(
			/* translators: %s: post date. */
            '%s',
			$modified_time
		);
		$modified = '<span class="modified-on">' . $modified_time . '</span>'; // WPCS: XSS OK.
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'aryx' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				$post_category = sprintf( esc_html__( 'Posted in %1$s', 'aryx' ) , $categories_list ); // WPCS: XSS OK.
			}
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'aryx' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				$post_tags = sprintf( esc_html__( 'Tagged %1$s', 'aryx' ) , $tags_list ); // WPCS: XSS OK.
			}
		}
		$categories = empty($post_category) ? '' : '<span class="cat-links">' . $post_category . '</span>';
		$tags = empty($post_tags) ? '' : '<span class="tags-links">' . $post_tags . '</span>';
		$author = '<span class="author vcard">' . sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'By %s', 'post author', 'aryx' ),
			'<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
		) . '</span>'; // WPCS: XSS OK.
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			$comments = get_comments_number() . ' Comment<span class="screen-reader-text"> on ' . get_the_title() . '</span>';
		}
		$comment_count = empty( $comments ) ? '' : '<span class="comments-link">' . $comments . '</span>';
		if ( is_single() ) {
			$meta_parts = get_theme_mod( 'aryx_f_archive_entry_meta_s_single_post_p_blog', array( 
				'published',
				'categories',
				'author'
			) );
			foreach ( $meta_parts as $meta_part ) {
                echo wp_kses(${$meta_part}, array(
                    'span' => array(
                        'class' => array(),
                    ),
                ));
			}
		} else {
			$meta_parts = get_theme_mod( 'aryx_f_archive_entry_meta_s_blog_archive_p_blog', array( 
				'published',
				'categories',
				'author'
			) );
			foreach ( $meta_parts as $meta_part ) {
                echo wp_kses(${$meta_part}, array(
                    'span' => array(
                        'class' => array(),
                    ),
                ));
			}
		}
		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'aryx' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;
if ( ! function_exists( 'aryx_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function aryx_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}
		if ( is_singular() ) :
			?>
			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->
		<?php else : ?>
		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
			the_post_thumbnail( 'post-thumbnail', array(
				'alt' => the_title_attribute( array(
					'echo' => false,
				) ),
			) );
			?>
		</a>
		<?php
		endif; // End is_singular().
	}
endif;