<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Aryx
 * @since 1,0
 */

get_header();
?>

	<?php
		$default_content_layout = get_theme_mod( 'aryx_f_default_content_layout_s_container_p_layout', 'fixed-width' );
		$archive_content_layout = get_theme_mod( 'aryx_f_archive_content_layout_s_container_p_layout', 'default-width' );

		if ( $archive_content_layout == 'default-width' ) {

			if ( $default_content_layout == 'fixed-width' ) {
				echo '<div class="container">';
			} elseif ( $default_content_layout == 'full-width' ) {
				echo '<div class="container-fluid">';
			}

		} elseif ( $archive_content_layout == 'fixed-width' ) {
			echo '<div class="container">';
		} elseif ( $archive_content_layout == 'full-width' ) {
			echo '<div class="container-fluid">';
		}
	?>

		<div class="row">
			<?php if ( get_header_image() ) : ?>
				<div class="col-md-12">
				    <div id="site-header">
				        <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
				            <img src="<?php header_image(); ?>" width="<?php echo absint( get_custom_header()->width ); ?>" height="<?php echo absint( get_custom_header()->height ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
				        </a>
				    </div>
			    </div>
			<?php endif; ?>

			<?php
				$global_archive_sidebar_layout = get_theme_mod( 'aryx_f_archive_sidebar_layout_s_sidebar_p_layout', '' );
				$global_default_sidebar_layout = get_theme_mod( 'aryx_f_default_sidebar_layout_s_sidebar_p_layout', 'right-sidebar' );

				/* Check if left sidebar is selected and output accordingly */

				if ( $global_archive_sidebar_layout == '' ) {

					if ( $global_default_sidebar_layout == 'left-sidebar' ) {
						get_sidebar();
					}

				} elseif ( $global_archive_sidebar_layout == 'left-sidebar' ) {
					get_sidebar();
				}

				/* Content Area Col Class */

				if ( $global_archive_sidebar_layout == '' ) {

					if ( $global_default_sidebar_layout == 'left-sidebar' || $global_default_sidebar_layout == 'right-sidebar' ) {
						$content_area_class = 'col-md-9';
					} else {
						$content_area_class = 'col-md-12';
					}

				} elseif ( $global_archive_sidebar_layout == 'left-sidebar' || $global_archive_sidebar_layout == 'right-sidebar' ) {
					$content_area_class = 'col-md-9';
				} else {
					$content_area_class = 'col-md-12';
				}
			?>

			<div id="primary content" class="content-area <?php echo $content_area_class; ?>">

				<?php
					if ( have_posts() ) {

						while ( have_posts() ) {
							the_post();

							get_template_part( 'template-parts/content', get_post_type() );

						}

						the_posts_navigation();

					} else {

						get_template_part( 'template-parts/content', 'none' );

					}
				?>

			</div><!-- /#primary -->

			<?php

				/* Check if right sidebar is selected and output accordingly */

				if ( $global_archive_sidebar_layout == '' ) {

					if ( $global_default_sidebar_layout == 'right-sidebar' ) {
						get_sidebar();
					}

				} elseif ( $global_archive_sidebar_layout == 'right-sidebar' ) {
					get_sidebar();
				}
			?>

		</div> <!-- /.row -->

	</div> <!-- /.container (/.container-fluid) -->

<?php
get_footer();
