<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

get_header( 'shop' );
?>

	<?php
		$archive_content_layout = get_theme_mod( 'aryx_f_archive_content_layout_s_container_p_layout', 'default-width' );
		$default_content_layout = get_theme_mod( 'aryx_f_default_content_layout_s_container_p_layout', 'fixed-width' );
		$show_breadcrumb = get_theme_mod( 'aryx_f_show_breadcrumb_s_breadcrumb_p_header', '1' );
		if ( $archive_content_layout == 'default-width' ) {
			if ( $default_content_layout == 'fixed-width' ) {
				echo '<div class="container">';
			} elseif ( $default_content_layout == 'full-width' ) {
				echo '<div class="container-fluid">';
			}
		} elseif ( $archive_content_layout == 'fixed-width' ) {
			echo '<div class="container">';
		} elseif ( $archive_content_layout == 'full-width' ) {
			echo '<div class="container-fluid">';
		}
	?>
		<?php $show_breadcrumb == 1 ? woocommerce_breadcrumb() : '' ?>
		<div class="row">
			<?php
				$archive_sidebar_layout = get_theme_mod( 'aryx_f_archive_sidebar_layout_s_sidebar_p_layout', 'default-sidebar' );
				$default_sidebar_layout = get_theme_mod( 'aryx_f_default_sidebar_layout_s_sidebar_p_layout', 'right-sidebar' );
				/* Check if left sidebar is selected and output accordingly */
				if ( $archive_sidebar_layout == 'default-sidebar' ) {
					if ( $default_sidebar_layout == 'left-sidebar' ) {
						get_sidebar();
					}
				} elseif ( $archive_sidebar_layout == 'left-sidebar' ) {
					get_sidebar();
				}
				/* Content Area Col Class */
				if ( $archive_sidebar_layout == 'default-sidebar' ) {
					if ( $default_sidebar_layout == 'left-sidebar' || $default_sidebar_layout == 'right-sidebar' ) {
						$content_area_class = 'col-md-9';
					} else {
						$content_area_class = 'col-md-12';
					}
				} elseif ( $archive_sidebar_layout == 'left-sidebar' || $archive_sidebar_layout == 'right-sidebar' ) {
					$content_area_class = 'col-md-9';
				} else {
					$content_area_class = 'col-md-12';
				}
			?>
			<div id="primary content" class="content-area <?php echo $content_area_class; ?>">

<?php
/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
//do_action( 'woocommerce_before_main_content' );

?>
<header class="woocommerce-products-header">
	<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
		<h1 class="woocommerce-products-header__title page-title"><?php woocommerce_page_title(); ?></h1>
	<?php endif; ?>

	<?php
	/**
	 * Hook: woocommerce_archive_description.
	 *
	 * @hooked woocommerce_taxonomy_archive_description - 10
	 * @hooked woocommerce_product_archive_description - 10
	 */
	do_action( 'woocommerce_archive_description' );
	?>
</header>
<?php
if ( woocommerce_product_loop() ) {

	/**
	 * Hook: woocommerce_before_shop_loop.
	 *
	 * @hooked woocommerce_output_all_notices - 10
	 * @hooked woocommerce_result_count - 20
	 * @hooked woocommerce_catalog_ordering - 30
	 */
	do_action( 'woocommerce_before_shop_loop' );

	woocommerce_product_loop_start();

	if ( wc_get_loop_prop( 'total' ) ) {
		while ( have_posts() ) {
			the_post();

			/**
			 * Hook: woocommerce_shop_loop.
			 */
			do_action( 'woocommerce_shop_loop' );

			wc_get_template_part( 'content', 'product' );
		}
	}

	woocommerce_product_loop_end();

	/**
	 * Hook: woocommerce_after_shop_loop.
	 *
	 * @hooked woocommerce_pagination - 10
	 */
	do_action( 'woocommerce_after_shop_loop' );
} else {
	/**
	 * Hook: woocommerce_no_products_found.
	 *
	 * @hooked wc_no_products_found - 10
	 */
	do_action( 'woocommerce_no_products_found' );
}

/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
//do_action( 'woocommerce_after_main_content' );

/**
 * Hook: woocommerce_sidebar.
 *
 * @hooked woocommerce_get_sidebar - 10
 */
//do_action( 'woocommerce_sidebar' );
?>

</div> <!-- /#primary -->
			<?php
				/* Check if right sidebar is selected and output accordingly */
				if ( $archive_sidebar_layout == 'default-sidebar' ) {
					if ( $default_sidebar_layout == 'right-sidebar' ) {
						get_sidebar();
					}
				} elseif ( $archive_sidebar_layout == 'right-sidebar' ) {
					get_sidebar();
				}
			?>
		</div> <!-- /.row -->
	</div> <!-- /.container (/.container-fluid) -->

<?php
get_footer( 'shop' );
